@@ -6,30 +6,31 @@ from . import bind as _bind
 from . import cyclictuple as _cyclictuple
 from . import duration as _duration
 from . import enums as _enums
+from . import indicators as _indicators
 from . import iterate as iterate_
-from . import markups as _markups
 from . import overrides as _overrides
 from . import pcollections as _pcollections
 from . import pitch as _pitch
 from . import score as _score
 from . import select as _select
 from . import setclass as _setclass
+from . import tweaks as _tweaks
 from . import verticalmoment as _verticalmoment
 
 
-def _attach(label, leaf, *, deactivate=False, tag=None):
-    _bind.attach(label, leaf, deactivate=deactivate, tag=tag)
+def _attach(label, leaf, *, deactivate=False, direction=None, tag=None):
+    _bind.attach(label, leaf, deactivate=deactivate, direction=direction, tag=tag)
 
 
 def _color_leaf(leaf, color, *, deactivate=False, tag=None):
     if isinstance(leaf, _score.Skip):
         color = color[1:]
-        comment = _overrides.LilyPondLiteral(f"% {color}", format_slot="before")
+        comment = _indicators.LilyPondLiteral(f"% {color}", site="before")
         _attach(comment, leaf, deactivate=deactivate, tag=tag)
     else:
         assert color.startswith("#")
         string = rf"\abjad-color-music #'{color[1:]}"
-        literal = _overrides.LilyPondLiteral(string)
+        literal = _indicators.LilyPondLiteral(string)
         _attach(literal, leaf)
     return leaf
 
@@ -275,16 +276,16 @@ def color_note_heads(argument, color_map=pc_number_to_color) -> None:
                 pc = _pitch.NumberedPitchClass(number)
                 color = color_map.get(pc, None)
                 if color is not None:
-                    _overrides.tweak(note_head, literal=True).Accidental.color = color
-                    _overrides.tweak(note_head).color = color
+                    _tweaks.tweak(note_head, rf"\tweak Accidental.color {color}")
+                    _tweaks.tweak(note_head, rf"\tweak color {color}")
         elif isinstance(leaf, _score.Note):
             note_head = leaf.note_head
             number = note_head.written_pitch.number
             pc = _pitch.NumberedPitchClass(number)
             color = color_map[pc.number]
             if color is not None:
-                _overrides.tweak(leaf.note_head, literal=True).Accidental.color = color
-                _overrides.tweak(leaf.note_head).color = color
+                _tweaks.tweak(leaf.note_head, rf"\tweak Accidental.color {color}")
+                _tweaks.tweak(leaf.note_head, rf"\tweak color {color}")
 
 
 def remove_markup(argument) -> None:
@@ -330,11 +331,11 @@ def remove_markup(argument) -> None:
 
     """
     for leaf in iterate_.leaves(argument):
-        _bind.detach(_markups.Markup, leaf)
+        _bind.detach(_indicators.Markup, leaf)
 
 
 def vertical_moments(
-    argument, direction=_enums.Up, prototype=None, *, deactivate=False, tag=None
+    argument, direction=_enums.UP, prototype=None, *, deactivate=False, tag=None
 ):
     r'''
     Labels vertical moments.
@@ -673,7 +674,7 @@ def vertical_moments(
         elif prototype is _pitch.NumberedPitch:
             leaves = vertical_moment.leaves
             generator = iterate_.pitches(leaves)
-            pitches = _pcollections.PitchSegment.from_pitches(generator)
+            pitches = _pcollections.PitchSegment(generator)
             if not pitches:
                 continue
             pitch_numbers = [str(pitch.number) for pitch in pitches]
@@ -681,7 +682,7 @@ def vertical_moments(
         elif prototype is _pitch.NumberedPitchClass:
             leaves = vertical_moment.leaves
             generator = iterate_.pitches(leaves)
-            pitches = _pcollections.PitchSegment.from_pitches(generator)
+            pitches = _pcollections.PitchSegment(generator)
             if not pitches:
                 continue
             pitch_classes = [pitch.pitch_class.number for pitch in pitches]
@@ -734,7 +735,7 @@ def vertical_moments(
             assert isinstance(prototype, _setclass.SetClass)
             leaves = vertical_moment.leaves
             generator = iterate_.pitches(leaves)
-            pitch_class_set = _pcollections.PitchClassSet.from_pitches(generator)
+            pitch_class_set = _pcollections.PitchClassSet(generator)
             if not pitch_class_set:
                 continue
             set_class = _setclass.SetClass.from_pitch_class_set(
@@ -751,16 +752,16 @@ def vertical_moments(
         else:
             raise TypeError(f"unknown prototype {prototype!r}.")
         assert string is not None
-        label = _markups.Markup(rf"\markup \tiny {string}", direction=direction)
-        if direction is _enums.Up:
+        label = _indicators.Markup(rf"\markup \tiny {string}")
+        if direction is _enums.UP:
             leaf = vertical_moment.start_leaves[0]
         else:
             leaf = vertical_moment.start_leaves[-1]
-        _attach(label, leaf, deactivate=deactivate, tag=tag)
+        _attach(label, leaf, deactivate=deactivate, direction=direction, tag=tag)
 
 
 def with_durations(
-    argument, *, denominator=None, direction=_enums.Up, in_seconds: bool = False
+    argument, *, denominator=None, direction=_enums.UP, in_seconds: bool = False
 ):
     r"""
     Labels logical ties in ``argument`` with durations.
@@ -830,14 +831,11 @@ def with_durations(
             duration = duration.with_denominator(denominator)
         pair = duration.pair
         numerator, denominator = pair
-        label = _markups.Markup(
-            rf"\markup \fraction {numerator} {denominator}",
-            direction=direction,
-        )
-        _attach(label, logical_tie.head)
+        label = _indicators.Markup(rf"\markup \fraction {numerator} {denominator}")
+        _attach(label, logical_tie.head, direction=direction)
 
 
-def with_indices(argument, direction=_enums.Up, prototype=None) -> None:
+def with_indices(argument, direction=_enums.UP, prototype=None) -> None:
     r"""
     Labels logical ties in ``argument`` with indices.
 
@@ -1039,13 +1037,13 @@ def with_indices(argument, direction=_enums.Up, prototype=None) -> None:
         generator = iterate_.components(argument, prototype=prototype)
     items = list(generator)
     for index, item in enumerate(items):
-        label = _markups.Markup(rf"\markup {index}", direction=direction)
+        label = _indicators.Markup(rf"\markup {index}")
         leaves = _select.leaves(item)
         first_leaf = leaves[0]
-        _attach(label, first_leaf)
+        _attach(label, first_leaf, direction=direction)
 
 
-def with_intervals(argument, direction=_enums.Up, prototype=None) -> None:
+def with_intervals(argument, direction=_enums.UP, prototype=None) -> None:
     r"""
     Labels consecutive notes in ``argument`` with intervals.
 
@@ -1255,33 +1253,20 @@ def with_intervals(argument, direction=_enums.Up, prototype=None) -> None:
         next_leaf = _iterate._get_leaf(note, 1)
         if isinstance(next_leaf, _score.Note):
             interval = _pitch.NamedInterval.from_pitch_carriers(note, next_leaf)
-            if prototype is _pitch.NamedInterval:
-                label = _markups.Markup(rf"\markup {interval}", direction=direction)
-            elif prototype is _pitch.NamedIntervalClass:
-                label = _markups.Markup(
-                    rf"\markup {_pitch.NamedIntervalClass(interval)}",
-                    direction=direction,
-                )
-            elif prototype is _pitch.NumberedInterval:
-                label = _markups.Markup(
-                    rf"\markup {_pitch.NumberedInterval(interval)}",
-                    direction=direction,
-                )
-            elif prototype is _pitch.NumberedIntervalClass:
-                label = _markups.Markup(
-                    rf"\markup {_pitch.NumberedIntervalClass(interval)}",
-                    direction=direction,
-                )
-            elif prototype is _pitch.NumberedInversionEquivalentIntervalClass:
-                label = _markups.Markup(
-                    rf"\markup {_pitch.NumberedInversionEquivalentIntervalClass(interval)}",
-                    direction=direction,
-                )
+            interval = prototype(interval)
+            if hasattr(interval, "name"):
+                label = _indicators.Markup(rf"\markup {interval.name}")
+            elif isinstance(interval, _pitch.NumberedInversionEquivalentIntervalClass):
+                label = _indicators.Markup(rf"\markup {interval.number}")
+            elif isinstance(
+                interval, _pitch.NumberedIntervalClass | _pitch.NumberedInterval
+            ):
+                label = _indicators.Markup(rf"\markup {interval.signed_string}")
             if label is not None:
-                _attach(label, note)
+                _attach(label, note, direction=direction)
 
 
-def with_pitches(argument, direction=_enums.Up, locale=None, prototype=None):
+def with_pitches(argument, direction=_enums.UP, locale=None, prototype=None):
     r"""
     Labels logical ties in ``argument`` with pitches.
 
@@ -1551,7 +1536,7 @@ def with_pitches(argument, direction=_enums.Up, locale=None, prototype=None):
                 string = leaf.written_pitch.get_name(locale=locale)
                 if "#" in string:
                     string = '"' + string + '"'
-                label = _markups.Markup(rf"\markup {{ {string} }}", direction=direction)
+                label = _indicators.Markup(rf"\markup {{ {string} }}")
             elif isinstance(leaf, _score.Chord):
                 pitches = leaf.written_pitches
                 pitches = reversed(pitches)
@@ -1561,42 +1546,32 @@ def with_pitches(argument, direction=_enums.Up, locale=None, prototype=None):
                     name = '"' + name + '"'
                     names.append(name)
                 string = " ".join(names)
-                label = _markups.Markup(
-                    rf"\markup \column {{ {string} }}",
-                    direction=direction,
-                )
+                label = _indicators.Markup(rf"\markup \column {{ {string} }}")
         elif prototype is _pitch.NumberedPitch:
             if isinstance(leaf, _score.Note):
                 pitch = leaf.written_pitch.number
-                label = _markups.Markup(rf"\markup {pitch}", direction=direction)
+                label = _indicators.Markup(rf"\markup {pitch}")
             elif isinstance(leaf, _score.Chord):
                 pitches = leaf.written_pitches
                 pitches = reversed(pitches)
                 pitches = [str(_.number) for _ in pitches]
                 string = " ".join(pitches)
-                label = _markups.Markup(
-                    rf"\markup \column {{ {string} }}",
-                    direction=direction,
-                )
+                label = _indicators.Markup(rf"\markup \column {{ {string} }}")
         elif prototype is _pitch.NumberedPitchClass:
             if isinstance(leaf, _score.Note):
                 pitch = leaf.written_pitch.pitch_class.number
-                label = _markups.Markup(rf"\markup {pitch}", direction=direction)
+                label = _indicators.Markup(rf"\markup {pitch}")
             elif isinstance(leaf, _score.Chord):
                 pitches = leaf.written_pitches
                 pitches = reversed(pitches)
                 pitches = [str(_.pitch_class.number) for _ in pitches]
                 string = " ".join(pitches)
-                label = _markups.Markup(
-                    rf"\markup \column {{ {string} }}",
-                    direction=direction,
-                )
+                label = _indicators.Markup(rf"\markup \column {{ {string} }}")
         if label is not None:
-            label = dataclasses.replace(label, direction=direction)
-            _attach(label, leaf)
+            _attach(label, leaf, direction=direction)
 
 
-def with_set_classes(argument, direction=_enums.Up, prototype=None):
+def with_set_classes(argument, direction=_enums.UP, prototype=None):
     r"""
     Labels selections ``argument`` with set-classes.
 
@@ -1745,7 +1720,7 @@ def with_set_classes(argument, direction=_enums.Up, prototype=None):
     assert isinstance(prototype, _setclass.SetClass), repr(prototype)
     for selection in argument:
         generator = iterate_.pitches(selection)
-        pitch_class_set = _pcollections.PitchClassSet.from_pitches(generator)
+        pitch_class_set = _pcollections.PitchClassSet(generator)
         if not pitch_class_set:
             continue
         set_class = _setclass.SetClass.from_pitch_class_set(
@@ -1754,10 +1729,9 @@ def with_set_classes(argument, direction=_enums.Up, prototype=None):
             transposition_only=prototype.transposition_only,
         )
         string = str(set_class)
-        string = rf'\markup \tiny \line {{ "{string}" }}'
-        label = _markups.Markup(string, direction=direction)
+        label = _indicators.Markup(rf'\markup \tiny \line {{ "{string}" }}')
         leaf = selection[0]
-        _attach(label, leaf)
+        _attach(label, leaf, direction=direction)
 
 
 def with_start_offsets(
@@ -1777,7 +1751,7 @@ def with_start_offsets(
 
         >>> string = r"\times 2/3 { c'4 d'4 e'4 ~ } e'4 ef'4"
         >>> staff = abjad.Staff(string)
-        >>> abjad.label.with_start_offsets(staff, direction=abjad.Up)
+        >>> abjad.label.with_start_offsets(staff, direction=abjad.UP)
         Duration(1, 1)
 
         >>> abjad.override(staff).TextScript.staff_padding = 4
@@ -1894,7 +1868,7 @@ def with_start_offsets(
 
     Returns total duration.
     """
-    direction = direction or _enums.Up
+    direction = direction or _enums.UP
     if global_offset is not None:
         assert isinstance(global_offset, _duration.Duration)
     for logical_tie in iterate_.logical_ties(argument):
@@ -1913,12 +1887,10 @@ def with_start_offsets(
         if brackets:
             string = f"[{string}]"
         if markup_command is not None:
-            string = rf"{markup_command} {{ {string} }}"
-            label = _markups.Markup(string, direction=direction)
+            label = _indicators.Markup(rf"{markup_command} {{ {string} }}")
         else:
-            string = rf"\markup {{ {string} }}"
-            label = _markups.Markup(string, direction=direction)
-        _attach(label, logical_tie.head)
+            label = _indicators.Markup(rf"\markup {{ {string} }}")
+        _attach(label, logical_tie.head, direction=direction)
     total_duration = _duration.Duration(timespan.stop_offset)
     if global_offset is not None:
         total_duration += global_offset
@@ -2044,7 +2016,7 @@ class ColorMap:
         return set(pcs).issubset(set(self._color_dictionary.keys()))
 
     @property
-    def pairs(self) -> typing.List[typing.Tuple[int, str]]:
+    def pairs(self) -> list[tuple[int, str]]:
         """
         Gets pairs.
 
