@@ -1,11 +1,9 @@
-import dataclasses
 import typing
 
 from . import _inspect
-from . import bundle as _bundle
-from . import enums as _enums
+from . import contributions as _contributions
 from . import illustrators as _illustrators
-from . import markups as _markups
+from . import indicators as _indicators
 from . import ratio as _ratio
 from . import score as _score
 from . import typings as _typings
@@ -58,7 +56,7 @@ class MetricModulation:
         >>> metric_modulation = abjad.MetricModulation(
         ...     left_rhythm=abjad.Note("c'4"),
         ...     right_rhythm=abjad.Tuplet((4, 5), "c'4"),
-        ...     )
+        ... )
 
         >>> lilypond_file = abjad.LilyPondFile(
         ...     [r'\include "abjad.ily"', metric_modulation]
@@ -78,7 +76,7 @@ class MetricModulation:
         >>> metric_modulation = abjad.MetricModulation(
         ...     left_rhythm=abjad.Note("c16."),
         ...     right_rhythm=abjad.Tuplet((2, 3), "c8"),
-        ...     )
+        ... )
 
         >>> lilypond_file = abjad.LilyPondFile(
         ...     [r'\include "abjad.ily"', metric_modulation]
@@ -100,7 +98,7 @@ class MetricModulation:
         >>> metric_modulation = abjad.MetricModulation(
         ...     left_rhythm=abjad.Note("c'4"),
         ...     right_rhythm=notes,
-        ...     )
+        ... )
 
         >>> lilypond_file = abjad.LilyPondFile(
         ...     [r'\include "abjad.ily"', metric_modulation]
@@ -198,7 +196,7 @@ class MetricModulation:
         >>> metric_modulation = abjad.MetricModulation(
         ...     left_rhythm=abjad.Note("c'4"),
         ...     right_rhythm=tuplet,
-        ...     )
+        ... )
 
         >>> lilypond_file = abjad.LilyPondFile(
         ...     [r'\include "abjad.ily"', metric_modulation]
@@ -302,8 +300,8 @@ class MetricModulation:
         >>> metric_modulation = abjad.MetricModulation(
         ...     left_rhythm=abjad.Note("c4"),
         ...     right_rhythm=abjad.Note("c8."),
-        ...     )
-        >>> abjad.attach(metric_modulation, staff[3])
+        ... )
+        >>> abjad.attach(metric_modulation, staff[3], direction=abjad.UP)
         >>> abjad.override(staff).TextScript.staff_padding = 2.5
 
         >>> lilypond_file = abjad.LilyPondFile([r'\include "abjad.ily"', score])
@@ -334,8 +332,6 @@ class MetricModulation:
 
     """
 
-    ### CLASS VARIABLES ###
-
     __slots__ = (
         "_hide",
         "_left_markup",
@@ -345,7 +341,7 @@ class MetricModulation:
         "_scale",
     )
 
-    ### INITIALIZER ###
+    directed: typing.ClassVar[bool] = True
 
     def __init__(
         self,
@@ -353,9 +349,9 @@ class MetricModulation:
         right_rhythm,
         *,
         hide: bool = False,
-        left_markup: _markups.Markup = None,
-        right_markup: _markups.Markup = None,
-        scale: typing.Tuple[_typings.Number, _typings.Number] = (1, 1),
+        left_markup: _indicators.Markup = None,
+        right_markup: _indicators.Markup = None,
+        scale: tuple[_typings.Number, _typings.Number] = (1, 1),
     ) -> None:
         self._hide = bool(hide)
         left_rhythm = self._initialize_rhythm(left_rhythm)
@@ -364,16 +360,14 @@ class MetricModulation:
         self._right_rhythm = right_rhythm
         self._right_rhythm = right_rhythm
         if left_markup is not None:
-            assert isinstance(left_markup, _markups.Markup)
+            assert isinstance(left_markup, _indicators.Markup)
         self._left_markup = left_markup
         if right_markup is not None:
-            assert isinstance(right_markup, _markups.Markup)
+            assert isinstance(right_markup, _indicators.Markup)
         self._right_markup = right_markup
         assert isinstance(scale, tuple), repr(scale)
         self._scale = scale
 
-    ### SPECIAL METHODS ###
-
     def __eq__(self, argument) -> bool:
         """
         Is true when ``argument`` is another metric modulation with the same
@@ -384,17 +378,17 @@ class MetricModulation:
             >>> metric_modulation_1 = abjad.MetricModulation(
             ...     left_rhythm=abjad.Note("c'4"),
             ...     right_rhythm=abjad.Note("c'4."),
-            ...     )
+            ... )
             >>> metric_modulation_2 = abjad.MetricModulation(
             ...     left_rhythm=abjad.Tuplet((2, 3), [abjad.Note("c'4")]),
             ...     right_rhythm=abjad.Note("c'4"),
-            ...     )
+            ... )
             >>> maker = abjad.NoteMaker()
             >>> notes = maker([0], [(5, 16)])
             >>> metric_modulation_3 = abjad.MetricModulation(
             ...     left_rhythm=abjad.Note("c'4"),
             ...     right_rhythm=notes,
-            ...     )
+            ... )
 
             >>> metric_modulation_1.ratio
             Ratio(numbers=(2, 3))
@@ -443,23 +437,6 @@ class MetricModulation:
         """
         return f"{type(self).__name__}(left_rhythm={self.left_rhythm!r}, right_rhythm={self.right_rhythm!r})"
 
-    def __str__(self) -> str:
-        r"""
-        Gets string representation of metric modulation.
-
-        ..  container:: example
-
-            >>> metric_modulation = abjad.MetricModulation(
-            ...     left_rhythm=abjad.Tuplet((2, 3), [abjad.Note("c'4")]),
-            ...     right_rhythm=abjad.Note("c'4"),
-            ...     )
-
-            >>> print(str(metric_modulation))
-            \markup \abjad-metric-modulation-tuplet-lhs #2 #0 #2 #3 #2 #0 #'(1 . 1)
-
-        """
-        return str(self._get_markup())
-
     ### PRIVATE METHODS ###
 
     def _get_lilypond_command_string(self):
@@ -491,21 +468,22 @@ class MetricModulation:
         return string
 
     def _get_lilypond_format(self):
-        return str(self)
+        markup = self._get_markup()
+        return markup.string
 
-    def _get_lilypond_format_bundle(self, component=None):
-        bundle = _bundle.LilyPondFormatBundle()
+    def _get_contributions(self, *, component=None, wrapper=None):
+        contributions = _contributions.ContributionsBySite()
         if not self.hide:
             markup = self._get_markup()
-            markup = dataclasses.replace(markup, direction=_enums.Up)
-            markup_format_pieces = markup._get_format_pieces()
-            bundle.after.markup.extend(markup_format_pieces)
-        return bundle
+            contributions = markup._get_contributions(
+                component=component, wrapper=wrapper
+            )
+        return contributions
 
     def _get_markup(self):
         string = self._get_lilypond_command_string()
         if string is not None:
-            markup = _markups.Markup(rf"\markup {string}")
+            markup = _indicators.Markup(rf"\markup {string}")
             return markup
         strings = []
         string = _illustrators.selection_to_score_markup_string(self.left_rhythm)
@@ -516,7 +494,7 @@ class MetricModulation:
         strings.extend(string.split("\n"))
         string = "\n".join(strings)
         string = rf"\markup {{ {string} }}"
-        markup = _markups.Markup(string)
+        markup = _indicators.Markup(string)
         return markup
 
     def _get_markup_arguments(self):
@@ -606,7 +584,7 @@ class MetricModulation:
         return self._hide
 
     @property
-    def left_markup(self) -> typing.Optional[_markups.Markup]:
+    def left_markup(self) -> _indicators.Markup | None:
         """
         Gets left markup of metric modulation.
 
@@ -615,7 +593,7 @@ class MetricModulation:
             >>> metric_modulation = abjad.MetricModulation(
             ...     left_rhythm=abjad.Note("c'4"),
             ...     right_rhythm=abjad.Note("c'4."),
-            ...     )
+            ... )
             >>> metric_modulation.left_markup
 
         """
@@ -631,7 +609,7 @@ class MetricModulation:
             >>> metric_modulation = abjad.MetricModulation(
             ...     left_rhythm=abjad.Note("c'4"),
             ...     right_rhythm=abjad.Note("c'4."),
-            ...     )
+            ... )
             >>> metric_modulation.left_rhythm
             [Note("c'4")]
 
@@ -649,7 +627,7 @@ class MetricModulation:
             >>> metric_modulation = abjad.MetricModulation(
             ...     left_rhythm=abjad.Tuplet((2, 3), [abjad.Note("c'4")]),
             ...     right_rhythm=abjad.Note("c'4"),
-            ...     )
+            ... )
             >>> metric_modulation.ratio
             Ratio(numbers=(2, 3))
 
@@ -661,7 +639,7 @@ class MetricModulation:
         return ratio
 
     @property
-    def right_markup(self) -> typing.Optional[_markups.Markup]:
+    def right_markup(self) -> _indicators.Markup | None:
         r"""Gets right markup of metric modulation.
 
         ..  container:: example
@@ -669,7 +647,7 @@ class MetricModulation:
             >>> metric_modulation = abjad.MetricModulation(
             ...     left_rhythm=abjad.Note("c'4"),
             ...     right_rhythm=abjad.Note("c'4."),
-            ...     )
+            ... )
             >>> metric_modulation.right_markup
 
         """
@@ -685,7 +663,7 @@ class MetricModulation:
             >>> metric_modulation = abjad.MetricModulation(
             ...     left_rhythm=abjad.Note("c'4"),
             ...     right_rhythm=abjad.Note("c'4."),
-            ...     )
+            ... )
             >>> metric_modulation.right_rhythm
             [Note("c'4.")]
 
@@ -693,7 +671,7 @@ class MetricModulation:
         return self._right_rhythm
 
     @property
-    def scale(self) -> typing.Tuple[_typings.Number, _typings.Number]:
+    def scale(self) -> tuple[_typings.Number, _typings.Number]:
         r"""
         Gets scale of output markup.
 
@@ -707,8 +685,8 @@ class MetricModulation:
             ...     left_rhythm=abjad.Note("c4"),
             ...     right_rhythm=abjad.Note("c8."),
             ...     scale=(0.5, 0.5),
-            ...     )
-            >>> abjad.attach(metric_modulation, staff[3])
+            ... )
+            >>> abjad.attach(metric_modulation, staff[3], direction=abjad.UP)
             >>> abjad.override(staff).TextScript.staff_padding = 2.5
 
             >>> lilypond_file = abjad.LilyPondFile([r'\include "abjad.ily"', score])
